function [U,C] = RitzCompTrans(Th)
% Computes the unique unit upper Hessenberg matrix H with prescribed Ritz values based on the Ritz value companion transform U
% Input:
%       Th             - upper triangular matrix Th of order k whose jth column contains the prescribed Ritz values for the jth iteration 
% Output:
%       U              - The Ritz value companion transform
%       C              - The companion matrix
n=length(Th(:,1));
U = eye(n);
for j=1:n-1
    p = poly(Th(1:j,j));
    U(1:j,j+1)=p(j+1:-1:2);
end
p = poly(Th(:,n));
C = zeros(n,n);
C(:,n)=-p(n+1:-1:2);
C(2:n,1:n-1)=eye(n-1);